@@ -252,7 +252,7 @@ class ExportExcelMixin:
     export_fields = None        # 需要导出的字段
     extra_fields_dc = None      # 最后的verbose_name转换字典, 如: { 'ming_cheng': '哈哈哈名称' }
 
-    use_django_pandas_to_export_file_threshold = 50000  # 数据过多时则使用django-pandas生成csv临时文件, 然后返回文件流.
+    use_django_pandas_to_export_file_threshold = 5000  # 数据过多时则使用django-pandas生成csv临时文件, 然后返回文件流.
 
     export_asc = False      # 按id升序导出 --- 不怎么需要这个字段了
     add_index = False       # 导出时增加索引列
@@ -421,6 +421,8 @@ class ImportMixin:
     # raise_error_to_debug = True     # debug模式
     raise_error_to_debug = False     # debug模式
 
+    single_import_threshold = 500  # 是否显示进度条的数据条数阈值
+
     workers = 1  # 导入时启用的线程数
     bulk_size = 100000       # 批处理数量, 已被workers取代
 
@@ -712,7 +714,7 @@ class ImportMixin:
                 from ..django.conf import db_engine
                 use_sqlite3 = 'sqlite3' in db_engine        # sqlite3只允许单线程save, 但可以多线程check
 
-                single_import_flag = n < 500 or (bulk_size and n <= bulk_size)      # 是否单线程导入
+                single_import_flag = n <= self.single_import_threshold and (bulk_size and n <= bulk_size)      # 是否单线程导入
                 multi_single_import_flag = bulk_size and n <= bulk_size         # 是否先返回然后再开另一个线程处理数据
 
                 print(f'--- workers: {workers} --- bulk_size: {bulk_size}, single_import_flag: {single_import_flag}')
