@@ -114,7 +114,11 @@ class ContentTypeAdmin(BaseAdmin):
 
     def get_object_name(self, obj):
         base_model = get_base_model(obj)
-        ret = base_model._meta.object_name
+        try:
+            ret = base_model._meta.object_name
+        except Exception as e:
+            ContentType.objects.get(id=obj.id).delete()
+            raise ModuleNotFoundError(f'没找到[{obj}]对应的base_model, 将删除obj! 请稍后刷新重试!')
         return ret
 
     get_object_name.short_description = '模型对象名'
