@@ -3,6 +3,7 @@
 """
 
 from .. import pure
+import base64
 
 import math
 import pandas as pd
@@ -44,6 +45,8 @@ from django.db import models as m
 from django.db import connection
 from copy import deepcopy
 from .conf import db_engine
+import numpy as np
+from django.core.cache import cache
 
 
 def get_list(query_dc, key):
@@ -98,7 +101,7 @@ def get_key_from_request_data_or_self_obj(request_data, self_obj, key, get_type=
 
 def set_query_dc_value(query_dc: (QueryDict, dict), new_dc: dict):
     assert isinstance(query_dc, (dict, QueryDict)), 'query_dc必须是`QueryDict`或`dict`类型!'
-    if isinstance(query_dc, dict):
+    if not hasattr(query_dc, "_mutable"):
         query_dc.update(new_dc)
         return query_dc
 
@@ -399,13 +402,12 @@ def conv_to_queryset(obj) -> QuerySet:
     return ret
 
 
-def paginate_qsls_to_dcls(qsls, serializer, page: int, per_page=16, context=None):
+def _paginate_qsls_to_dcls(qsls, serializer, page: int, per_page=16, context=None):
     """
     * 手动分页函数
 
     - 指定模型的queryset_ls和serializer, 然后按给定的page和per_page参数获取分页后的数据
     """
-
     page_size = int(per_page)
 
     if page_size == 0:
@@ -437,6 +439,113 @@ def paginate_qsls_to_dcls(qsls, serializer, page: int, per_page=16, context=None
             raise Exception(f'--- paginate_qsls_to_dcls错误!!! 2022/2/25, error: {e}')
     else:
         dc_ls = serializer(page_obj, many=True, context=context).data
+
+    return dc_ls, page_dc
+
+
+def get_count(qs_ls, expired_time=0):
+    if not expired_time:
+        return qs_ls.count()
+
+    _qs_ls = qs_ls.order_by().values("pk")
+    query = f"cache__{_qs_ls.query}"
+    # query = base64.b64encode(bytes(query, 'utf-8')).hex()  # 最好是64进制之类
+    # print("cache query --- ", type(query), len(query), "---", query)
+
+    count = cache.get(query)
+    if count is None:
+        count = _qs_ls.count()
+
+    if expired_time:
+        cache.set(query, expired_time)
+    return count
+
+
+def paginate_qsls_to_dcls(qs_ls, serializer, page: int, per_page=16, context=None, cache_expired_time=0, get_page_dc=True):
+    """
+    性能优化分页器
+
+    :param qs_ls: queryset查询集
+    :param serializer: 序列化器
+    :param page: 页码
+    :param per_page: 每页数量
+    :param context: 上下文
+    :param cache_expired_time: `get_count`的缓存时间
+    :param get_page_dc: 是否获取page_dc
+    :return: 分页后的数据dc_ls
+    """
+    from math import ceil
+
+    if 0:
+        # from search import models as search_models
+        # qsls = search_models.TitleBase.objects.filter(
+        #     wu_li_qi_shi_ye_ma__isnull=False,
+        #     wu_li_jie_shu_ye_ma__isnull=False,
+        #     yin_shua_ye_ma__isnull=False,
+        #     book_name__contains="苗族",
+        # )
+        # qsls = 1
+        dc_ls = serializer(qs_ls[20: 30], many=True, context=context).data
+        # dc_ls = serializer(qsls.order_by()[20: 30], many=True, context=context).data
+        # dc_ls = serializer(qsls.order_by('pk')[20: 30], many=True, context=context).data
+        # dc_ls = serializer(qsls.order_by('pk')[20: 30], many=True, context=context).data
+
+        # F(order_type).asc(nulls_first=True)
+        print('--- paginate_qsls_to_dcls.tt --- 1', tt.now(1))
+
+        return dc_ls, {}
+
+    page_size = int(per_page)
+
+    if get_page_dc:      # 性能问题
+        # if cache_expired_time:
+        #     count_items = get_count(qs_ls, expired_time=cache_expired_time)
+        # else:
+        #     count_items = qs_ls.count()
+        count_items = get_count(qs_ls, expired_time=cache_expired_time)
+        total_pages = ceil(count_items / page_size)
+    else:
+        count_items = 0
+        total_pages = None
+
+    if page_size == 0:
+        page_dc = {
+            "count_items": count_items,
+            "total_pages": None,
+            "page_size": page_size,
+            "p": int(page)
+        }
+        return [], page_dc
+
+    p = int(page)
+    page_dc = {
+        "count_items": count_items,
+        "total_pages": total_pages,
+        # "num_pages": total_pages,
+        "page_size": page_size,
+        "p": p
+    }
+
+    # if count_items == 0:
+    #     return [], page_dc
+
+    start_i = (p - 1) * page_size
+    start_i = 0 if start_i < 0 else start_i
+    end_i = p * page_size
+    end_i = count_items if end_i > count_items else end_i
+    page_obj = qs_ls[start_i: end_i + 1]
+
+    context = {} if not context else context  # 避免序列化报错
+
+    # --- 处理单个Model和多个Model的情况
+    if serializer.__class__.__name__ == 'function':
+        try:
+            dc_ls = serializer(page_obj, context=context)
+        except Exception as e:
+            raise Exception(f'*** paginate_qsls_to_dcls错误! error: {e}')
+    else:
+        dc_ls = serializer(page_obj, many=True, context=context).data
+
     return dc_ls, page_dc
 
 
@@ -477,14 +586,15 @@ def order_by_order_type_ls(queryset, order_type_ls) -> QuerySet:
     else:
         ls = []
         for order_type in order_type_ls:
-            if isinstance(order_type, str):
-                if order_type.startswith('-'):
-                    order_type1 = order_type[1:]
-                    ls.append(F(order_type1).desc(nulls_last=True))
-                else:
-                    ls.append(F(order_type).asc(nulls_first=True))
-            else:
-                ls.append(order_type)
+            ls.append(order_type)
+            # if isinstance(order_type, str):
+            #     if order_type.startswith('-'):
+            #         order_type1 = order_type[1:]
+            #         ls.append(F(order_type1).desc(nulls_last=True))     # 这个`nulls_last`之类操作极大影响性能!
+            #     else:
+            #         ls.append(F(order_type).asc(nulls_first=True))
+            # else:
+            #     ls.append(order_type)
         ret = queryset.order_by(*ls)
     return ret
 
@@ -956,9 +1066,19 @@ def get_statistic_fields_result(queryset, statistic_fields, statistic_size=5, de
             if loc_ls:
                 dc_ls = conv_queryset_to_dc_ls(statistic_qsv)
                 df = pd.DataFrame(dc_ls)
-                df = df.set_index(dc_name)
-                df = df.loc[loc_ls]
-                df = df.reset_index()
+                key_series = df[dc_name]
+                new_df = pd.DataFrame([], columns=df.columns)
+                for loc_i in loc_ls:
+                    if loc_i in key_series.values:
+                        index = np.where(key_series == loc_i)[0][0]
+                        _v = df.iloc[index:index+1, :]
+                        new_df = new_df.append(df.iloc[index])
+                        new_df.index = list(range(len(new_df)))
+                    else:
+                        _v = pd.DataFrame([[loc_i, 0]], columns=df.columns)
+                        new_df = new_df.append(_v)
+
+                df = new_df
                 statistic_qsv = conv_df_to_serializer_data(df)
         else:
             statistic_qsv = field_qsv.annotate(counts=m.Count('pk')).order_by(*ordering)
