@@ -2,6 +2,10 @@ from .utils import *
 from rest_framework.views import APIView
 from .mixins import MyCreateModelMixin, MyUpdateModelMixin, MyDestroyModelMixin
 
+from bdtime import Time
+
+t1 = Time()
+
 
 class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
     """
@@ -12,6 +16,11 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
             GET /api/index/BaseList/?order_type=-id&page_size=4&p=1
         - Retrieve:
             GET /api/index/BaseList/5/
+
+    ------ 性能优化
+    - 性能优化:
+        - get_page_dc: 是否每次都返回分页信息, 设置为false或者让前端控制
+        - cache_expired_time__get_count: `get_count`的缓存时间, 设置大一点
     """
 
     _name = 'BaseListView'  # 这个在自动生成wiki时要用到
@@ -35,6 +44,7 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
     list_serializer_class = None  # list对应的serializer_class
 
     retrieve_filter_field = 'pk'  # 详情页的查询字段名, 默认为 {{url}}/app/view/pk , 可由前端指定.
+    cache_expired_time__get_count = 0      # get_count方法的cache有效时间
 
     method = None  # 中间变量, 记录请求是什么类型, list/retrieve等
     _tmp = None  # 无意义, 用来处理数据
@@ -50,7 +60,7 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
     add_host_prefix_to_media_url = True  # 是否返回文件的时候加上当前域名的prefix
 
     flat_dc_ls = False      # 是否展平为list然后返回. 只有在返回一个字段的时候才生效.
-    add_page_dc = True      # 是否增加`page_dc`
+    get_page_dc = True      # 是否返回`page_dc`
 
     def __new__(cls, *args, **kwargs):
         ret = super().__new__(cls, *args, **kwargs)
@@ -119,7 +129,19 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
 
         page_size = query_dc.get('page_size', self.pagination_class.page_size)
         p = query_dc.get('p', 1)
-        data, page_dc = paginate_qsls_to_dcls(qs_ls, self.get_serializer_class(), page=p, per_page=page_size)
+        context = self.get_serializer_context()
+
+        get_page_dc = get_key_from_request_data_or_self_obj(request, self, 'get_page_dc', get_type='bool')
+
+        data, page_dc = paginate_qsls_to_dcls(
+            qs_ls,
+            self.get_serializer_class(),
+            page=p,
+            per_page=page_size,
+            context=context,
+            cache_expired_time=self.cache_expired_time__get_count,
+            get_page_dc=get_page_dc,
+        )
         ret = {
             'page_dc': page_dc,
             'data': data
@@ -240,9 +262,10 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         status = 200
         msg = 'ok'
 
+        t1.__init__()
+
         # --- 得到list方法的queryset
         self.queryset = self.get_list_queryset()
-
         if not isinstance(self.queryset, QuerySet):
             self.queryset = self.queryset.objects.all()
 
@@ -253,12 +276,7 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         try:
             ret = self.list(request)
         except Exception as e:
-            # 页码无效的情况, 404 Not Found
             raise e
-            # ret = None
-            # my_api_assert_function(ret, f'List error! --- {e}', 404)
-            # status = 404
-            # msg = str(e)
         return ret, status, msg
 
     def get_request_data(self) -> dict:
@@ -440,9 +458,18 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         context = self.get_serializer_context()
 
         serializer_class = self.get_serializer_class()
-        resp, page_dc = paginate_qsls_to_dcls(self.queryset, serializer_class, page=p, per_page=page_size,
-                                              context=context)
-        ret = self.conv_data_format(resp, page_dc)
+        get_page_dc = get_key_from_request_data_or_self_obj(query_dc, self, 'get_page_dc', get_type='bool')
+
+        data, page_dc = paginate_qsls_to_dcls(
+            self.queryset,
+            serializer_class,
+            page=p,
+            per_page=page_size,
+            context=context,
+            cache_expired_time=self.cache_expired_time__get_count,
+            get_page_dc=get_page_dc
+        )
+        ret = self.conv_data_format(data, page_dc)
         return ret
 
     def conv_data_format(self, data, page_dc):
@@ -451,8 +478,8 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         if flat_dc_ls and data and len(data[0]) == 1:
             data = [list(i.values())[0] for i in data]
 
-        add_page_dc = get_key_from_request_data_or_self_obj(self.get_request_data(), self, 'add_page_dc', get_type='bool')
-        if add_page_dc:
+        get_page_dc = get_key_from_request_data_or_self_obj(self.get_request_data(), self, 'get_page_dc', get_type='bool')
+        if get_page_dc:
             ret = {
                 'page_dc': page_dc,
                 'data': data,
