@@ -7,12 +7,15 @@ import platform
 import shutil
 
 
-assert "Linux" in platform.platform(), "必须是`Linux`版本!"
+assert platform.system() == 'Linux', "必须是`Linux`版本!"
 
-if 'Ubuntu' in platform.platform():
+
+if os.system('which apt') == 0:
     is_ubuntu = True
-else:
+elif os.system('which yum') == 0:
     is_ubuntu = False
+else:
+    raise TypeError("安装包管理器不是apt也不是yum?")
 
 package_manager = "apt-get" if is_ubuntu else "yum"
 os.system(f"{package_manager} install -y nginx")
@@ -24,11 +27,9 @@ else:
     dst = "/etc/nginx/conf.d/default.conf"
     src = os.path.join(os.path.dirname(__file__), "default")
 
-
-assert os.path.exists(src), f'`nginx`配置文件`default`的路径[{src}]不存在!'
-
-
+print(f'--- src: [{src}] -> dst: [{dst}]')
 shutil.copy2(src, dst)
 os.system("service nginx restart")
 
-print("nginx配置已更新.")
+print("nginx配置已更新, 记得收集静态文件`python manage.py collectstatic --noinput`")
+
